CommonArgs

Struct CommonArgs 

pub(crate) struct CommonArgs {
    config_search_paths: Vec<PathBuf>,
}
Arguments shared between admin and serve commands.

Fields

config_search_paths: Vec<PathBuf>

Look for a configuration file at these locations. If no configuration file is found at the first location, the second one is consulted, and so on.

Implementations