pub(crate) struct CommonArgs {
config_search_paths: Vec<PathBuf>,
}Expand description
Arguments shared between admin and serve commands.
Fields
config_search_paths: Vec<PathBuf>Look for a configuration file at these locations. If no configuration file is found at the first location, the second one is consulted, and so on.
Implementations
Sourceimpl CommonArgs
impl CommonArgs
pub fn load_config(&self) -> Result<Config>
fn load_config_inner(&self) -> Result<Config>